from mastercardapicore import *

# import apis resourceconfig
from mastercardmatch.resourceconfig import *


# import apis into api package
from mastercardmatch.acquirercontactrequest import *
from mastercardmatch.addterminatedmerchant import *
from mastercardmatch.retroactiveinquirydetailsrequest import *
from mastercardmatch.retroactiveinquiryrequest import *
from mastercardmatch.terminationinquiryhistoryrequest import *
from mastercardmatch.terminationinquiryrequest import *
